# Sample Test passing with nose and pytest
import os
import shutil
import tempfile
import zipfile

from snapshottest import snapshot

import jj2c


FIXTURES_DIR = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), 'fixtures')


def test_compile():
  text = jj2c.compile('hello {{ name }}!', {'name': 'world'})
  assert text == 'hello world!'


def test_compile_file(snapshot):
  fpath = os.path.join(FIXTURES_DIR, 'hello.tpl')
  text = jj2c.compile_file(fpath, {'name': 'compile_file'})
  snapshot.assert_match(text)


def collect_contents(folder):
  contents = {}
  for root, dirs, files in os.walk(folder):
    for fname in files:
      dir_name = root[len(folder) + 1:]
      fname_key = os.path.join(dir_name, fname)
      fname_real = os.path.join(root, fname)
      with open(fname_real, 'r') as f:
        contents[fname_key] = f.read()
  return contents


def collect_contents_zip(zippath):
  dir_out = tempfile.mkdtemp()
  try:
    shutil.unpack_archive(zippath, dir_out)
    return collect_contents(dir_out)
  finally:
    shutil.rmtree(dir_out)


def test_BatchCompiler_1(snapshot):
  dir_tpl = os.path.join(FIXTURES_DIR, 'a')
  dir_out = tempfile.mkdtemp()
  variables = {'a': 'AAA', 'b': 'BBB'}
  try:
    batch = jj2c.BatchCompiler(variables, dir_tpl, dir_out)
    batch.compile()
    snapshot.assert_match(
        collect_contents(dir_out))
  finally:
    shutil.rmtree(dir_out)


def test_compile_zip_2_zip(snapshot):
  dir_tpl = os.path.join(FIXTURES_DIR, 'a')
  dir_out = tempfile.mkdtemp()
  tpl_zip = os.path.join(dir_out, 'a.zip')
  o_zip = os.path.join(dir_out, 'o.zip')

  shutil.make_archive(tpl_zip[:-4], 'zip', dir_tpl)
  variables = {'a': 'AAA zip', 'b': 'BBB zip'}

  try:
    jj2c.compile_zip_2_zip(tpl_zip, o_zip, variables)
    snapshot.assert_match(collect_contents_zip(o_zip))
  finally:
    shutil.rmtree(dir_out)


def test_compile_dir_2_zip(snapshot):
  dir_tpl = os.path.join(FIXTURES_DIR, 'a')
  dir_out = tempfile.mkdtemp()
  o_zip = os.path.join(dir_out, 'o.zip')

  variables = {
      'a': 'AAA compile_dir_to_zip',
      'b': 'BBB compile_dir_to_zip'}

  try:
    jj2c.compile_dir_2_zip(dir_tpl, o_zip, variables)
    snapshot.assert_match(collect_contents_zip(o_zip))
  finally:
    shutil.rmtree(dir_out)


def test_compile_zip_2_dir(snapshot):
  dir_tpl = os.path.join(FIXTURES_DIR, 'a')
  dir_out = tempfile.mkdtemp()
  tpl_zip = os.path.join(dir_out, 'a.zip')

  shutil.make_archive(tpl_zip[:-4], 'zip', dir_tpl)
  variables = {'a': 'AAA zip', 'b': 'BBB zip'}

  dir_out2 = os.path.join(dir_out, 'output')

  try:
    jj2c.compile_zip_2_dir(tpl_zip, dir_out2, variables)
    snapshot.assert_match(collect_contents(dir_out2))
  finally:
    shutil.rmtree(dir_out)



import os

import jj2c


FIXTURES_DIR = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), 'fixtures')


def test_basic_yaml_as_str():
  ve = jj2c.VariableExtractor('a: 123')
  assert ve.extract() == ('yaml', {'a': 123})


def test_basic_json_as_str():
  ve = jj2c.VariableExtractor('{"a": 123}')
  assert ve.extract() == ('json', {'a': 123})


def test_basic_toml_as_str():
  ve = jj2c.VariableExtractor('a=123')
  assert ve.extract() == ('toml', {'a': 123})


def test_basic_toml_as_str():
  ve = jj2c.VariableExtractor('a=123')
  assert ve.extract() == ('toml', {'a': 123})


def test_basic_yaml_as_file(snapshot):
  vars_file = os.path.join(FIXTURES_DIR, 'vars.yaml')
  ve = jj2c.VariableExtractor(vars_file)
  fmt, data = ve.extract()
  assert fmt == 'yaml'
  snapshot.assert_match(data)


def test_basic_json_as_file(snapshot):
  vars_file = os.path.join(FIXTURES_DIR, 'vars.json')
  ve = jj2c.VariableExtractor(vars_file)
  fmt, data = ve.extract()
  assert fmt == 'json'
  snapshot.assert_match(data)


def test_basic_toml_as_file(snapshot):
  vars_file = os.path.join(FIXTURES_DIR, 'vars.toml')
  ve = jj2c.VariableExtractor(vars_file)

  fmt, data = ve.extract()
  data['owner']['dob'] = data['owner']['dob'].isoformat()
  assert fmt == 'toml'
  snapshot.assert_match(data)



from codecs import open
from os import path
from setuptools import setup, find_packages
import re


module_name = 'jj2c'
with open("{name}/__init__.py".format(name=module_name), encoding='utf-8') as f:
  __version__ = re.search(
    '^__version__\s*=\s*[\'\"]([^\'\"]+)', f.read(),
    flags=re.I | re.M).group(1)


here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
  long_description = f.read()

# get the dependencies and installs
with open(path.join(here, 'requirements.txt'), encoding='utf-8') as f:
  all_reqs = f.read().split('\n')

install_requires = [x.strip() for x in all_reqs if 'git+' not in x]
dependency_links = [x.strip().replace('git+', '') for x in all_reqs if x.startswith('git+')]

setup(
    name='jj2c',
    version=__version__,
    description='Jinja2 compiler',
    long_description=long_description,
    url='https://github.com/tly1980/jj2c',
    download_url='https://github.com/tly1980/jj2c/tarball/' + __version__,
    license='BSD',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
    ],
    keywords='',
    packages=find_packages(exclude=['docs', 'tests*']),
    include_package_data=True,
    author='Tom Tang',
    scripts=['bin/jj2c'],
    install_requires=install_requires,
    dependency_links=dependency_links,
    author_email='tly1980@gmail.com'
)



# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot


snapshots = Snapshot()

snapshots['test_compile_zip 1'] = {
    'b/f2': '''f2 -- BBB zip
There out her child sir his lived.''',
    'f1': '''f1 -- AAA zip
In post mean shot ye.'''
}

snapshots['test_compile_dir_to_zip 1'] = {
    'b/f2': '''f2 -- BBB compile_dir_to_zip
There out her child sir his lived.''',
    'f1': '''f1 -- AAA compile_dir_to_zip
In post mean shot ye.'''
}

snapshots['test_BatchCompiler_1 1'] = {
    'b/c/base': '''head:

base - head


body:

base - body
''',
    'b/f2': '''f2 -- BBB
There out her child sir his lived.''',
    'f1': '''head:

base - head


body:

f1 -- AAA
In post mean shot ye.
'''
}

snapshots['test_compile_dir_2_zip 1'] = {
    'b/c/base': '''head:

base - head


body:

base - body
''',
    'b/f2': '''f2 -- BBB compile_dir_to_zip
There out her child sir his lived.''',
    'f1': '''head:

base - head


body:

f1 -- AAA compile_dir_to_zip
In post mean shot ye.
'''
}

snapshots['test_compile_zip_2_zip 1'] = {
    'b/c/base': '''head:

base - head


body:

base - body
''',
    'b/f2': '''f2 -- BBB zip
There out her child sir his lived.''',
    'f1': '''head:

base - head


body:

f1 -- AAA zip
In post mean shot ye.
'''
}

snapshots['test_compile_file 1'] = '''hello compile_file!

a is 
b is '''

snapshots['test_compile_zip_2_dir 1'] = {
    'b/c/base': '''head:

base - head


body:

base - body
''',
    'b/f2': '''f2 -- BBB zip
There out her child sir his lived.''',
    'f1': '''head:

base - head


body:

f1 -- AAA zip
In post mean shot ye.
'''
}
